==> qiskit_braket_provider-0.0.3.tar.gz: qiskit_braket_provider-0.0.3/README.md <==
# Qiskit-Braket provider

Qiskit-Braket provider to execute Qiskit programs on AWS quantum computing hardware devices through Amazon Braket.

### Table of Contents

##### For Users

1.  [Installation](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/docs/installation_guide.md)
2.  [Quickstart Guide](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/docs/quickstart_guide.md)
3.  [Tutorials](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/docs/tutorials/)
4.  [How-Tos](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/docs/how_tos/)
5.  [How to Give Feedback](#how-to-give-feedback)
6.  [Contribution Guidelines](#contribution-guidelines)
7.  [References and Acknowledgements](#references-and-acknowledgements)
8.  [License](#license)

##### For Developers/Contributors

1. [Contribution Guide](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/CONTRIBUTING.md)


----------------------------------------------------------------------------------------------------

### How to Give Feedback

We encourage your feedback! You can share your thoughts with us by:
- [Opening an issue](https://github.com/qiskit-community/qiskit-braket-plugin/issues) in the repository


----------------------------------------------------------------------------------------------------

### Contribution Guidelines

For information on how to contribute to this project, please take a look at our [contribution guidelines](CONTRIBUTING.md).


----------------------------------------------------------------------------------------------------

## References and Acknowledgements
[1] Qiskit https://qiskit.org/ \
[2] Qiskit-terra https://github.com/Qiskit/qiskit-terra \
[3] Amazon Braket Python SDK https://github.com/aws/amazon-braket-sdk-python


----------------------------------------------------------------------------------------------------

### License
[Apache License 2.0](LICENSE.txt)

==> qiskit_braket_provider-0.3.1.tar.gz: qiskit_braket_provider-0.3.1/README.md <==
# Qiskit-Braket provider

[![Latest Version](https://img.shields.io/pypi/v/qiskit-braket-provider.svg)](https://pypi.python.org/pypi/qiskit-braket-provider)
[![Supported Python Versions](https://img.shields.io/pypi/pyversions/qiskit-braket-provider.svg)](https://pypi.python.org/pypi/qiskit-braket-provider)
[![Build status](https://github.com/qiskit-community/qiskit-braket-provider/actions/workflows/test_latest_versions.yml/badge.svg?branch=main)](https://github.com/qiskit-community/qiskit-braket-provider/actions/workflows/test_latest_versions.yml)

Qiskit-Braket provider to execute Qiskit programs on AWS quantum computing hardware devices through Amazon Braket.

### Table of Contents

##### For Users

1.  [Installation](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/docs/installation_guide.md)
2.  [Quickstart Guide](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/docs/quickstart_guide.md)
3.  [Tutorials](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/docs/tutorials/)
4.  [How-Tos](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/docs/how_tos/)
5.  [How to Give Feedback](#how-to-give-feedback)
6.  [Contribution Guidelines](#contribution-guidelines)
7.  [References and Acknowledgements](#references-and-acknowledgements)
8.  [License](#license)

##### For Developers/Contributors

1. [Contribution Guide](https://github.com/qiskit-community/qiskit-braket-provider/blob/main/CONTRIBUTING.md)


----------------------------------------------------------------------------------------------------

### How to Give Feedback

We encourage your feedback! You can share your thoughts with us by:
- [Opening an issue](https://github.com/qiskit-community/qiskit-braket-plugin/issues) in the repository


----------------------------------------------------------------------------------------------------

### Contribution Guidelines

For information on how to contribute to this project, please take a look at our [contribution guidelines](CONTRIBUTING.md).


----------------------------------------------------------------------------------------------------

## References and Acknowledgements
[1] Qiskit https://www.ibm.com/quantum/qiskit \
[2] Amazon Braket Python SDK https://github.com/aws/amazon-braket-sdk-python


----------------------------------------------------------------------------------------------------

### License
[Apache License 2.0](LICENSE.txt)
